package src

import (
	"github.com/go-acme/lego/v4/platform/config/env"
	"gopkg.in/yaml.v3"
	"log"
	"os"
)

func ReadConfig() ClientConfig {
	InitConfig()
	file, err := os.ReadFile(getConfigFile())
	if err != nil {
		log.Fatal(err)
	}
	var conf ClientConfig
	err = yaml.Unmarshal(file, &conf)
	if err != nil {
		log.Fatal(err)
	}
	return conf
}

func InitConfig() {
	confFile := getConfigFile()
	_, err := os.Stat(confFile)

	if os.IsNotExist(err) {
		log.Println("客户端配置文件不存在，自动创建默认配置文件")
		conf := defaultConfig()
		file, err := os.Create(confFile)
		if err != nil {
			log.Fatal(err)
		}
		defer file.Close()
		data, err := yaml.Marshal(conf)
		if err != nil {
			log.Fatal(err)
		}
		_, err = file.Write(data)
		if err != nil {
			log.Fatal(err)
		}
	}
}

func FlushConfig() {
	ReadConfig()
}

func WriteConfig() {
	confFile := getConfigFile()
	data, err := yaml.Marshal(GetClientConfig())
	if err != nil {
		log.Fatal(err)
	}
	err = os.WriteFile(confFile, data, 0755)
	if err != nil {
		log.Fatal(err)
	}
}

func defaultConfig() *ClientConfig {
	return &ClientConfig{
		Server:       "",
		RsaPublicKey: "",
	}
}

func getConfigFile() string {
	return env.GetOrDefaultString(ENV_CLIENT_CONF_FILE, "config.yml")
}

const ENV_CLIENT_CONF_FILE = "ACME_MANA_CONF_FILE"
