package src

import (
	"crypto/x509"
	"github.com/go-acme/lego/v4/certificate"
)

// ClientConfig 客户端配置
type ClientConfig struct {
	Server       string
	RsaPublicKey string
	Domains      []Domain
}

// Domain 域名
type Domain struct {
	Name     string
	CertFile string
	KeyFile  string
	InfoFile string
}

// FindDomain 查找域名
func (conf *ClientConfig) FindDomain(name string) *Domain {
	for _, domain := range conf.Domains {
		if domain.Name == name {
			return &domain
		}
	}
	return nil
}

// Result 服务端统一响应格式
type Result struct {
	Code int
	Msg  string
	Data string
}

// SDomain 服务端域名配置结构
type SDomain struct {
	Name  string
	Email string
	Host  []string
}

// DomainData 证书相关信息
type DomainData struct {
	Fullchain string `json:"fullchain"`
	Key       string `json:"key"`
	Info      string `json:"info"`
}

// CertInfo 证书详情
type CertInfo struct {
	Cert certificate.Resource
	Info x509.Certificate
}
