package src

import (
	"encoding/json"
	"fmt"
	"io"
	"log"
	"net/http"
	"os"
)

// 服务端命令
func onServerCommand() {
	args := os.Args
	if len(args) < 3 {
		log.Fatal("参数错误, 请检查")
	}
	command := args[2]
	switch command {
	case "list":
		showServerList()
	default:
		log.Fatal("参数错误, 请检查")
	}
}

// 从服务端获取域名列表
func showServerList() {
	server := GetClientConfig().Server
	token, encryptToken := GenToken()
	url := server + "/api/v1/domain/list?token=" + encryptToken
	resp, err := http.Get(url)
	if err != nil {
		log.Fatal("获取服务端数据失败, 请检查 server 地址是否正确")
	}
	defer resp.Body.Close()
	body, err := io.ReadAll(resp.Body)
	if err != nil {
		log.Fatal(err)
	}
	result := Result{}
	err = json.Unmarshal(body, &result)
	if err != nil {
		log.Fatal(err)
	}
	if result.Code != 200 {
		log.Fatal("读取数据出错; ", result.Msg)
	}
	data := result.Data
	text := DecryptByToken(token, data)
	d := &[]SDomain{}
	err = json.Unmarshal([]byte(text), d)
	if err != nil {
		log.Fatal(err)
	}
	for i := range *d {
		domain := (*d)[i]
		fmt.Printf("- %s\n", domain.Name)
		fmt.Printf("\t认证域名: [ ")
		for j := range domain.Host {
			host := domain.Host[j]
			fmt.Printf("%s ", host)
		}
		fmt.Printf("]\n")
	}
}
